# Vyro 文档

Vyro 将 Python DX 与 Rust 执行引擎相结合，以实现高性能 API。

## What you can do

- 使用 `Vyro()` 构建异步 API
- 使用 `vyro run` 运行服务
- 使用 OpenAPI 生成 API 合约
- 通过可观察性和安全原语来运营生产服务

## 从这里开始

1.阅读【安装】(getting-started/installation.md)
2. 按照【快速入门】(getting-started/quickstart.md)
3. 在 [First API] 中构建您的第一个端点(getting-started/first-api.md)